@@ -22,5 +22,7 @@ urlpatterns = [
     path('update/', views.update),
     path('read-db/', views.read_db),
     path('write-db/', views.write_db),
+    path('fetch-web/', views.fetch_web),
+    path('fetch-web-action/', views.fetch_web_action),
     path('run-pipeline/', views.run_pipeline),
 ]
